@@ -1,7 +1,7 @@
 package App::LocaleCodesUtils;
 
-our $DATE = '2018-03-06'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2018-03-07'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -104,6 +104,37 @@ $res = gen_read_table_func(
 );
 die "Can't generate list_languages(): $res->[0] - $res->[1]" unless $res->[0] == 200;
 
+$res = gen_read_table_func(
+    name => 'list_scripts',
+    summary => 'List scripts',
+    table_data => sub {
+        require Locale::Script;
+        my @codes = Locale::Script::all_script_codes();
+        my @data;
+        for (@codes) {
+            push @data, [$_, Locale::Script::code2script($_)];
+        }
+        return { data=>\@data };
+    },
+    table_spec => {
+        summary => 'List of scripts',
+        fields => {
+            code => {
+                schema => 'str*',
+                pos => 0,
+                sortable => 1,
+            },
+            name => {
+                schema => 'str*',
+                pos => 1,
+                sortable => 1,
+            },
+        },
+        pk => 'code',
+    },
+);
+die "Can't generate list_scripts(): $res->[0] - $res->[1]" unless $res->[0] == 200;
+
 1;
 # ABSTRACT: Utilities related to locale codes
 
@@ -119,7 +150,7 @@ App::LocaleCodesUtils - Utilities related to locale codes
 
 =head1 VERSION
 
-This document describes version 0.001 of App::LocaleCodesUtils (from Perl distribution App-LocaleCodesUtils), released on 2018-03-06.
+This document describes version 0.002 of App::LocaleCodesUtils (from Perl distribution App-LocaleCodesUtils), released on 2018-03-07.
 
 =head1 DESCRIPTION
 
@@ -133,6 +164,8 @@ This distributions provides the following command-line utilities:
 
 =item * L<list-languages>
 
+=item * L<list-scripts>
+
 =back
 
 =head1 FUNCTIONS
@@ -614,6 +647,165 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 list_scripts
+
+Usage:
+
+ list_scripts(%args) -> [status, msg, result, meta]
+
+List scripts.
+
+REPLACE ME
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<code> => I<str>
+
+Only return records where the 'code' field equals specified value.
+
+=item * B<code.contains> => I<str>
+
+Only return records where the 'code' field contains specified text.
+
+=item * B<code.in> => I<array[str]>
+
+Only return records where the 'code' field is in the specified values.
+
+=item * B<code.is> => I<str>
+
+Only return records where the 'code' field equals specified value.
+
+=item * B<code.isnt> => I<str>
+
+Only return records where the 'code' field does not equal specified value.
+
+=item * B<code.max> => I<str>
+
+Only return records where the 'code' field is less than or equal to specified value.
+
+=item * B<code.min> => I<str>
+
+Only return records where the 'code' field is greater than or equal to specified value.
+
+=item * B<code.not_contains> => I<str>
+
+Only return records where the 'code' field does not contain specified text.
+
+=item * B<code.not_in> => I<array[str]>
+
+Only return records where the 'code' field is not in the specified values.
+
+=item * B<code.xmax> => I<str>
+
+Only return records where the 'code' field is less than specified value.
+
+=item * B<code.xmin> => I<str>
+
+Only return records where the 'code' field is greater than specified value.
+
+=item * B<detail> => I<bool> (default: 0)
+
+Return array of full records instead of just ID fields.
+
+By default, only the key (ID) field is returned per result entry.
+
+=item * B<fields> => I<array[str]>
+
+Select fields to return.
+
+=item * B<name> => I<str>
+
+Only return records where the 'name' field equals specified value.
+
+=item * B<name.contains> => I<str>
+
+Only return records where the 'name' field contains specified text.
+
+=item * B<name.in> => I<array[str]>
+
+Only return records where the 'name' field is in the specified values.
+
+=item * B<name.is> => I<str>
+
+Only return records where the 'name' field equals specified value.
+
+=item * B<name.isnt> => I<str>
+
+Only return records where the 'name' field does not equal specified value.
+
+=item * B<name.max> => I<str>
+
+Only return records where the 'name' field is less than or equal to specified value.
+
+=item * B<name.min> => I<str>
+
+Only return records where the 'name' field is greater than or equal to specified value.
+
+=item * B<name.not_contains> => I<str>
+
+Only return records where the 'name' field does not contain specified text.
+
+=item * B<name.not_in> => I<array[str]>
+
+Only return records where the 'name' field is not in the specified values.
+
+=item * B<name.xmax> => I<str>
+
+Only return records where the 'name' field is less than specified value.
+
+=item * B<name.xmin> => I<str>
+
+Only return records where the 'name' field is greater than specified value.
+
+=item * B<query> => I<str>
+
+Search.
+
+=item * B<random> => I<bool> (default: 0)
+
+Return records in random order.
+
+=item * B<result_limit> => I<int>
+
+Only return a certain number of records.
+
+=item * B<result_start> => I<int> (default: 1)
+
+Only return starting from the n'th record.
+
+=item * B<sort> => I<array[str]>
+
+Order records according to certain field(s).
+
+A list of field names separated by comma. Each field can be prefixed with '-' to
+specify descending order instead of the default ascending.
+
+=item * B<with_field_names> => I<bool>
+
+Return field names in each record (as hash/associative array).
+
+When enabled, function will return each record as hash/associative array
+(field name => value pairs). Otherwise, function will return each record
+as list/array (field value, field value, ...).
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =for Pod::Coverage ^(.+)$
 
 =head1 HOMEPAGE
